==> nextcloud-app-bookmarks-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/cs.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Záložky",
    "Failed to import one bookmark, because: " : "Nepodařilo se importovat jednu záložku, protože:",
    "Bookm." : "Záložky",
    "No file provided for import" : "Není k dispozici žádný soubor pro import",
    "Unsupported file type for import" : "Nepodporovaný typ souboru pro import",
    "Add a Bookmark" : "Přidat záložku",
    "Select" : "Vybrat",
    "Deselect" : "Zrušit výběr ",
    "Details" : "Podrobnosti",
    "Delete" : "Smazat",
    "Saved" : "Uloženo",
    "Tags" : "Štítky",
    "Description" : "Popis",
    "No bookmarks here." : "Nejsou zde žádné záložky.",
    "All bookmarks" : "Všechny záložky",
    "Untagged" : "Neoznačeno",
    "Shared" : "Sdílené",
    "Settings" : "Nastavení",
    "Bookmarklet" : "Záložky",
    "Add to {instanceName} " : "Přidat do {instanceName} ",
    "Recently added" : "Nedávno přidáno",
    "Most visited" : "Nejnavštěvovanější",
    "RSS Feed" : "RSS kanál",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Trvale odstraní z vašeho účtu všechny záložky. Tato operace je nevratná!",
    "Delete all bookmarks" : "Smazat všechny záložky",
    "Add to filter" : "Přidat do filtru",
    "Remove from filter" : "Odebrat z filtru",
    "Rename" : "Přejmenovat",
    "Open details" : "Otevřít podorobnosti",
    "An error occurred while trying to save the bookmark." : "Při pokusu o uložení záložky nastala chyba.",
    "Error" : "Chyba",
    "Uploading..." : "Nahrávání",
    "Import error" : "Import se nezdařil",
    "Import completed successfully." : "Import byl úspěšně dokončen",
    "Set tags" : "Nastavit štítky",
    "A Bookmark manager for Nextcloud" : "Správce záložek pro Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tato aplikace vám umožní ukládat a organizovat vaše oblíbené stránky na internetu a zároveň je synchronizuje přes vaše zařízení a prohlížeče. Mrkněte na neoficiální klienty: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Přidat do záložek",
    "This URL is already bookmarked! Overwrite?" : "Adresa URL stánky už je v záložkách! Přepsat ?",
    "The title of the page" : "Nadpis stránky",
    "The address of the page" : "Adresa stránky",
    "Description of the page" : "Popis stránky",
    "Save" : "Uložit",
    "Previews" : "Náhledy",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Pro zobrazování skutečných snímků webových stránek v záložkách, aplikace Záložky může pro jejich vytváření používat službu třetí strany.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Můžete se buď zdarma přihlásit na <a href=\"http://screeenly.com\">screeenly.com</a> nebo <a href=\"https://github.com/stefanzweifel/screeenly\">si nastavit vlastní server</a>.",
    "Screenly API URL" : "URL adresa aplikačního program. rozhraní služby Screenly",
    "Screenly API key" : "Klíč k aplikačnímu program. rozhraní služby Screenly",
    "Bookmarks feed" : "Kanál záložek"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-app-bookmarks-1%3A0.14.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/cs.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Záložky",
    "Failed to import one bookmark, because: " : "Nepodařilo se importovat jednu záložku, protože:",
    "No file provided for import" : "Není k dispozici žádný soubor pro import",
    "Unsupported file type for import" : "Nepodporovaný typ souboru pro import",
    "Add a Bookmark" : "Přidat záložku",
    "Add folder" : "Přidat složku",
    "Select" : "Vybrat",
    "Deselect" : "Zrušit výběr ",
    "Details" : "Podrobnosti",
    "Delete" : "Smazat",
    "Saved" : "Uloženo",
    "Tags" : "Štítky",
    "Description" : "Popis",
    "No bookmarks here." : "Nejsou zde žádné záložky.",
    "Favorites" : "Oblíbené",
    "Settings" : "Nastavení",
    "Bookmarklet" : "Záložky",
    "Add to {instanceName} " : "Přidat do {instanceName} ",
    "Recently added" : "Nedávno přidáno",
    "Most visited" : "Nejnavštěvovanější",
    "RSS Feed" : "RSS kanál",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Trvale odstraní z vašeho účtu všechny záložky. Tato operace je nevratná!",
    "Delete all bookmarks" : "Smazat všechny záložky",
    "Open details" : "Otevřít podorobnosti",
    "An error occurred while trying to save the bookmark." : "Při pokusu o uložení záložky nastala chyba.",
    "Error" : "Chyba",
    "Uncategorized" : "Nezařazené",
    "Import error" : "Import se nezdařil",
    "Import completed successfully." : "Import byl úspěšně dokončen",
    "Set tags" : "Nastavit štítky",
    "A Bookmark manager for Nextcloud" : "Správce záložek pro Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Tato aplikace vám umožní ukládat a organizovat vaše oblíbené stránky na internetu a zároveň je synchronizuje přes vaše zařízení a prohlížeče. Mrkněte na neoficiální klienty: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Přidat do záložek",
    "This URL is already bookmarked! Overwrite?" : "Adresa URL stánky už je v záložkách! Přepsat ?",
    "The title of the page" : "Nadpis stránky",
    "The address of the page" : "Adresa stránky",
    "Description of the page" : "Popis stránky",
    "Save" : "Uložit",
    "Previews" : "Náhledy",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Pro zobrazování skutečných snímků webových stránek v záložkách, aplikace Záložky může pro jejich vytváření používat službu třetí strany.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Můžete se buď zdarma přihlásit na <a href=\"http://screeenly.com\">screeenly.com</a> nebo <a href=\"https://github.com/stefanzweifel/screeenly\">si nastavit vlastní server</a>.",
    "Screenly API URL" : "URL adresa aplikačního program. rozhraní služby Screenly",
    "Screenly API key" : "Klíč k aplikačnímu program. rozhraní služby Screenly",
    "Bookmarks feed" : "Kanál záložek"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
